@@ -518,9 +518,6 @@ class Observation(models.Model):
                 return False
             return True
         if self.waterfall:
-            if (not self.waterfall.storage.exists(self.waterfall.name
-                                                  )) or self.waterfall.size == 0:
-                return False
             return True
         return False
 
@@ -535,8 +532,6 @@ class Observation(models.Model):
                 return False
             return True
         if self.payload:
-            if (not self.payload.storage.exists(self.payload.name)) or self.payload.size == 0:
-                return False
             return True
         return False
 
