@@ -1,11 +1,8 @@
 """Django database users model for SatNOGS Network"""
-from __future__ import absolute_import
-
 from django.contrib.auth.models import AbstractUser
 from django.core.validators import MaxLengthValidator
 from django.db import models
 from django.db.models.signals import post_save
-from django.utils.encoding import python_2_unicode_compatible
 from rest_framework.authtoken.models import Token
 
 
@@ -17,7 +14,6 @@ def gen_token(sender, instance, created, **kwargs):  # pylint: disable=W0613
         Token.objects.create(user=instance)
 
 
-@python_2_unicode_compatible
 class User(AbstractUser):
     """Model for SatNOGS users."""
 
